@@ -31,10 +31,10 @@ class JsonBaseSchema(TypedDict):
     hidden: NotRequired[Optional[bool]]
     group: NotRequired[Optional[str]]
     defaultValue: NotRequired[Optional[Union[str, int, bool]]]
+    store: NotRequired[Optional[bool]]
 
 
 class PluginJsonBaseSchema(JsonBaseSchema):
-    store: NotRequired[Optional[bool]]
     onSet: NotRequired[
         Union[Callable[[Any, Any], Awaitable[Union[None, Any]]], Callable[[Any, Any], Union[None, Any]]]
     ]
@@ -128,14 +128,10 @@ class JsonSchemaObjectWithButtons(JsonSchemaObject):
     buttons: tuple[JsonSchemaButton, NotRequired[JsonSchemaButton]]
 
 
-class JsonSchemaAnyOf(TypedDict):
-    anyOf: list["JsonSchema"]
-
-
 class JsonSchemaArray(JsonBaseSchema):
     type: Literal["array"]
     opened: NotRequired[bool]
-    items: NotRequired[Union["JsonSchema", JsonSchemaAnyOf]]
+    items: NotRequired["JsonSchema"]
 
 
 JsonSchema = Union[
@@ -206,7 +202,7 @@ class CameraInput(TypedDict):
     urls: StreamUrls
 
 
-CameraRoles = Literal["detect", "record", "stream", "snapshot", "none"]
+CameraRoles = Literal["high-resolution", "mid-resolution", "low-resolution", "snapshot", "none"]
 
 CameraExtensionWithoutHub = Literal[
     "prebuffer",
@@ -648,11 +644,14 @@ Interfaces = Literal["camera", "ptz", "prebuffer", "audioDetector", "motionDetec
 
 
 class CameraDelegate(metaclass=ABCMeta):
+    @abstractmethod
+    async def snapshot(self) -> bytes: ...
+
     @abstractmethod
     async def reboot(self) -> None: ...
 
 
-CameraDelegateMethodNames = Literal["reboot",]
+CameraDelegateMethodNames = Literal["reboot", "snapshot"]
 
 
 class CameraPrebufferDelegate(metaclass=ABCMeta):
@@ -680,30 +679,6 @@ class CameraPTZDelegate(metaclass=ABCMeta):
 CameraPTZDelegateMethodNames = Literal["moveAbsolute", "moveRelative", "moveContinuous", "stop"]
 
 
-class CameraMotionDetectionDelegate(metaclass=ABCMeta):
-    @abstractmethod
-    async def detectVideo(self, video_path: str) -> list[Detection]: ...
-
-
-CameraMotionDetectionDelegateMethodNames = Literal["detectVideo"]
-
-
-class CameraObjectDetectionDelegate(metaclass=ABCMeta):
-    @abstractmethod
-    async def detectImage(self, image: bytes, metadata: "ImageMetadata") -> list[Detection]: ...
-
-
-CameraObjectDetectionDelegateMethodNames = Literal["detectImage"]
-
-
-class CameraAudioDetectionDelegate(metaclass=ABCMeta):
-    @abstractmethod
-    async def detectAudio(self, audio: bytes) -> bool: ...
-
-
-CameraAudioDetectionDelegateMethodNames = Literal["detectAudio"]
-
-
 class CameraSource(Protocol):
     # from CameraInput
     id: str  # _id
@@ -756,7 +731,12 @@ DecoderFormat = Literal["yuv", "rgb"]
 class ImageMetadata(TypedDict):
     width: int
     height: int
-    format: Literal["rgb"]
+
+
+class AudioMetadata(TypedDict):
+    sampleRate: int
+    channels: int
+    format: str
 
 
 class FrameMetadata(TypedDict):
@@ -854,16 +834,13 @@ class CameraDevice(Protocol):
     on_battery_changed: Observable[BatteryState]
 
     stream_source: CameraSource
-    snapshot_source: CameraSource
-    recording_source: CameraSource
-    detection_source: CameraSource
+    snapshot_source: Optional[CameraSource]
+    high_resolution_source: Optional[CameraSource]
+    mid_resolution_source: Optional[CameraSource]
+    low_resolution_source: Optional[CameraSource]
 
     cameraDelegate: CameraDelegate
-    prebufferDelegate: CameraPrebufferDelegate
     ptzDelegate: CameraPTZDelegate
-    audioDetectorDelegate: CameraAudioDetectionDelegate
-    motionDetectorDelegate: CameraMotionDetectionDelegate
-    objectDetectorDelegate: CameraObjectDetectionDelegate
 
     @overload
     def set_delegate(self, name: Literal["cameraDelegate"], delegate: CameraDelegate) -> None: ...
@@ -871,18 +848,6 @@ class CameraDevice(Protocol):
     def set_delegate(self, name: Literal["prebufferDelegate"], delegate: CameraPrebufferDelegate) -> None: ...
     @overload
     def set_delegate(self, name: Literal["ptzDelegate"], delegate: CameraPTZDelegate) -> None: ...
-    @overload
-    def set_delegate(
-        self, name: Literal["audioDetectorDelegate"], delegate: CameraAudioDetectionDelegate
-    ) -> None: ...
-    @overload
-    def set_delegate(
-        self, name: Literal["motionDetectorDelegate"], delegate: CameraMotionDetectionDelegate
-    ) -> None: ...
-    @overload
-    def set_delegate(
-        self, name: Literal["objectDetectorDelegate"], delegate: CameraObjectDetectionDelegate
-    ) -> None: ...
 
     async def connect(self) -> None: ...
     async def disconnect(self) -> None: ...
@@ -1077,24 +1042,6 @@ class DeviceManager(Protocol):
     def remove_all_listeners(self, event: Optional[DeviceManagerEventType] = None) -> "DeviceManager": ...
 
 
-# SystemManager
-@runtime_checkable
-class SystemManager(Protocol):
-    def on(self, event: str, listener: Callback) -> "SystemManager": ...
-    def once(self, event: str, listener: Callback) -> "SystemManager": ...
-    def remove_listener(self, event: str, listener: Callback) -> "SystemManager": ...
-    def remove_all_listeners(self, event: str) -> "SystemManager": ...
-
-
-# PluginsManager
-@runtime_checkable
-class PluginsManager(Protocol):  # todo: add methods
-    def on(self, event: str, listener: Callback) -> "PluginsManager": ...
-    def once(self, event: str, listener: Callback) -> "PluginsManager": ...
-    def remove_listener(self, event: str, listener: Callback) -> "PluginsManager": ...
-    def remove_all_listeners(self, event: str) -> "PluginsManager": ...
-
-
 # camera storage
 P = TypeVar("P")
 
@@ -1191,8 +1138,6 @@ class PluginAPI(Protocol):
     config_service: PluginConfigService
     storage_controller: StorageController
     device_manager: DeviceManager
-    system_manager: SystemManager
-    plugins_manager: PluginsManager
 
     def on(self, event: APIEventType, listener: Callback) -> "PluginAPI": ...
     def once(self, event: APIEventType, listener: Callback) -> "PluginAPI": ...
@@ -1231,6 +1176,18 @@ class FormSubmitResponse(TypedDict):
     schema: NotRequired[FormSubmitSchema]
 
 
+class MotionDetectionPluginResponse(TypedDict):
+    filePath: str
+
+
+class ObjectDetectionPluginResponse(TypedDict):
+    detections: list[Detection]
+
+
+class AudioDetectionPluginResponse(TypedDict):
+    detected: bool
+
+
 class BasePlugin(metaclass=ABCMeta):
     @abstractmethod
     def __init__(self, logger: PluginLogger, api_instance: PluginAPI) -> None: ...
@@ -1238,3 +1195,30 @@ class BasePlugin(metaclass=ABCMeta):
     async def onFormSubmit(self, action_id: str, payload: Any) -> Union[FormSubmitResponse, None]: ...
     @abstractmethod
     def configure_cameras(self, cameras: list[CameraDevice]) -> None: ...
+
+
+class MotionDetectionPlugin(BasePlugin):
+    @abstractmethod
+    def interfaceSchema(self) -> Optional[RootSchema]: ...
+    @abstractmethod
+    async def detectMotion(
+        self, video_path: str, config: dict[str, Any]
+    ) -> MotionDetectionPluginResponse: ...
+
+
+class ObjectDetectionPlugin(BasePlugin):
+    @abstractmethod
+    def interfaceSchema(self) -> Optional[RootSchema]: ...
+    @abstractmethod
+    async def detectObjects(
+        self, image_path: str, metadata: ImageMetadata, config: dict[str, Any]
+    ) -> ObjectDetectionPluginResponse: ...
+
+
+class AudioDetectionPlugin(BasePlugin):
+    @abstractmethod
+    def interfaceSchema(self) -> Optional[RootSchema]: ...
+    @abstractmethod
+    async def detectAudio(
+        self, audio_path: str, metadata: AudioMetadata, config: dict[str, Any]
+    ) -> AudioDetectionPluginResponse: ...
